@@ -3,6 +3,7 @@ import copy
 import subprocess
 import sys
 
+from adam.config import Config
 from adam.repl_state import ReplState, RequiredState
 
 repl_cmds: list['Command'] = []
@@ -21,6 +22,7 @@ class Command:
     # Do not do child of child!!!
     @abstractmethod
     def run(self, cmd: str, state: ReplState):
+        Config().debug(cmd)
         if self._successor:
             return self._successor.run(cmd, state)
 
