@@ -36,7 +36,7 @@ from adam.commands.show.show_params import ShowParams
 from adam.commands.show.show_processes import ShowProcesses
 from adam.commands.show.show_repairs import ShowRepairs
 from adam.commands.show.show_storage import ShowStorage
-from adam.commands.show.show_version import ShowVersion
+from adam.commands.show.show_adam import ShowAdam
 from adam.commands.watch import Watch
 
 class ReplCommands:
@@ -44,23 +44,25 @@ class ReplCommands:
         cmds: list[Command] = ReplCommands.navigation() + ReplCommands.cassandra_check() + ReplCommands.cassandra_ops() + \
             ReplCommands.tools() + ReplCommands.app() + ReplCommands.exit()
 
+        intermediate_cmds: list[Command] = [Show(), App(), Reaper(), Repair()]
+        ic = [c.command() for c in intermediate_cmds]
         # 1. dedup commands
         deduped = []
         cs = set()
         for cmd in cmds:
-            if not cmd.command() in cs:
+            if cmd.command() not in cs and cmd.command() not in ic:
                 deduped.append(cmd)
                 cs.add(cmd.command())
         # 2. intermediate commands must be added to the end
-        deduped.extend([Show(), App(), Reaper(), Repair()])
+        deduped.extend(intermediate_cmds)
 
         # Command.print_chain(Command.chain(cmds))
 
-        return cmds
+        return deduped
 
     def navigation() -> list[Command]:
         return [Ls(), PreviewTable(), DeviceApp(), DevicePostgres(), DeviceCass(), Cd(), Pwd(), ClipboardCopy(),
-                GetParam(), SetParam(), ShowParams(), ShowKubectlCommands(), ShowLogin(), ShowVersion()]
+                GetParam(), SetParam(), ShowParams(), ShowKubectlCommands(), ShowLogin(), ShowAdam()]
 
     def cassandra_check() -> list[Command]:
         return [ShowCassandraStatus(), ShowCassandraVersion(), ShowRepairs(), ShowStorage(), ShowProcesses(), Check(), Issues(), NodeTool(), Report()]
