@@ -1,12 +1,18 @@
+import base64
 import getpass
 import os
+import traceback
 import requests
+from kubernetes import config
+import yaml
+
+from adam.k8s_utils.secrets import Secrets
 
 from .cred_cache import CredCache
 from .idp_session import IdpSession
 from .idp_login import IdpLogin
 from adam.config import Config
-from adam.utils import log
+from adam.utils import log, log2
 
 class Idp:
     ctrl_c_entered = False
@@ -23,8 +29,9 @@ class Idp:
         if use_token_from_env:
             if l0 := session.login_from_env_var():
                 return l0
-        if p := os.getenv("SERVER_PORT"):
-            res: requests.Response = requests.get(f'http://localhost:{p}')
+        if port := os.getenv("SERVER_PORT"):
+            token_server = Config().get('app.login.token-server-url', 'http://localhost:{port}').replace('{port}', port)
+            res: requests.Response = requests.get(token_server)
             if res.status_code == 200 and res.text:
                 return session.login_from_token(res.text)
 
@@ -37,8 +44,13 @@ class Idp:
                 if Idp.ctrl_c_entered:
                     Idp.ctrl_c_entered = False
 
-                default_user = CredCache().get_username() if use_cached_creds else None
-                Config().debug(f'User read from cache: {default_user} with use_cached: {use_cached_creds}')
+                default_user: str = None
+                if use_cached_creds:
+                    default_user = CredCache().get_username()
+                    log2(f'User read from cache: {default_user}')
+
+                if from_env := os.getenv('USERNAME'):
+                    default_user = from_env
                 if default_user and default_user != username:
                     session = IdpSession.create(default_user, app_host, app_host)
 
@@ -72,7 +84,27 @@ class Idp:
                     password = getpass.getpass(f'Password: ')
 
             if username and password:
+                try:
+                    kubeconfig_string = base64.b64decode(password.encode('ascii')).decode('utf-8')
+                    if kubeconfig_string.startswith('apiVersion: '):
+                        kubeconfig_dict = yaml.safe_load(kubeconfig_string)
+                        config.kube_config.load_kube_config_from_dict(kubeconfig_dict)
+                        log2('Kubectl file loaded')
+                        Secrets.list_secrets(os.getenv('NAMESPACE'))
+
+                        # if listing secrets does not fail, the kubeconfig string is good
+                        log2('Accepted kubeconfig file as password.')
+                        r = IdpLogin(None, None, None, username)
+                        log(f"You're signed in as {username}")
+
+                        return r
+                except:
+                    log2(traceback.format_exc)
+                    pass
+
                 r = session.authenticator.authenticate(session.idp_uri, app_host, username, password)
+                if r:
+                    log(f"You're signed in as {username}")
 
                 return r
         finally:
